@@ -194,7 +194,10 @@ function create_k8s_api_service {
     local service_cidr
     local kubelet_iface_ip
     local lb_name
+    local project_id
 
+    project_id=$(get_or_create_project \
+        "$KURYR_NEUTRON_DEFAULT_PROJECT" default)
     lb_name='default/kubernetes'
     service_cidr=$(openstack --os-cloud devstack-admin \
                              --os-region "$REGION_NAME" \
@@ -206,10 +209,10 @@ function create_k8s_api_service {
     k8s_api_clusterip=$(_cidr_range "$service_cidr" | cut -f1)
 
     create_load_balancer "$lb_name" "$k8s_api_clusterip" \
-        "$KURYR_NEUTRON_DEFAULT_SERVICE_SUBNET"
-    create_load_balancer_listener default/kubernetes:443 HTTPS 443 "$lb_name"
+        "$project_id" "$KURYR_NEUTRON_DEFAULT_SERVICE_SUBNET"
+    create_load_balancer_listener default/kubernetes:443 HTTPS 443 "$lb_name" "$project_id"
     create_load_balancer_pool default/kubernetes:443 HTTPS ROUND_ROBIN \
-        default/kubernetes:443 "$lb_name"
+        default/kubernetes:443 "$project_id" "$lb_name"
 
     local api_port
     if is_service_enabled openshift-master; then
@@ -219,7 +222,7 @@ function create_k8s_api_service {
     fi
 
     create_load_balancer_member "$(hostname)" "$kubelet_iface_ip" "$api_port" \
-        default/kubernetes:443 public-subnet "$lb_name"
+        default/kubernetes:443 public-subnet "$lb_name" "$project_id"
 }
 
 function configure_neutron_defaults {
@@ -393,6 +396,7 @@ function wait_for {
     local url
     local cacert_path
     local flags
+    local timeout=$KURYR_WAIT_TIMEOUT
     name="$1"
     url="$2"
     cacert_path=${3:-}
@@ -405,8 +409,12 @@ function wait_for {
         extra_flags=""
     fi
 
+    local start_time=$(date +%s)
     until curl -o /dev/null -sIf $extra_flags "$url"; do
         echo -n "."
+        local curr_time=$(date +%s)
+        local time_diff=$(($curr_time - $start_time))
+        [[ $time_diff -le $timeout ]] || die "Timed out waiting for $name"
         sleep 1
     done
     echo ""
