@@ -49,8 +49,9 @@ class LBaaSSpecHandler(k8s_base.ResourceEventHandler):
         lbaas_spec = self._get_lbaas_spec(service)
 
         if self._should_ignore(service):
-            LOG.debug("Skiping Kubernetes service without a selector as "
-                      "Kubernetes does not create an endpoint object for it.")
+            LOG.debug("Skiping Kubernetes service of an unsupported kind or"
+                      "without a selector as Kubernetes does not create an "
+                      "endpoint object for it.")
             return
 
         if self._has_lbaas_spec_changes(service, lbaas_spec):
@@ -68,7 +69,8 @@ class LBaaSSpecHandler(k8s_base.ResourceEventHandler):
 
     def _should_ignore(self, service):
         return (not(self._has_selector(service)) or
-                not(self._has_clusterip(service)))
+                not(self._has_clusterip(service)) or
+                not(self._is_supported_type(service)))
 
     def _has_selector(self, service):
         return service['spec'].get('selector')
@@ -307,13 +309,16 @@ class LoadBalancerHandler(k8s_base.ResourceEventHandler):
     def _sync_lbaas_members(self, endpoints, lbaas_state, lbaas_spec):
         changed = False
 
-        if self._remove_unused_members(endpoints, lbaas_state, lbaas_spec):
+        if (self._has_pods(endpoints) and
+                self._remove_unused_members(endpoints, lbaas_state,
+                                            lbaas_spec)):
             changed = True
 
         if self._sync_lbaas_pools(endpoints, lbaas_state, lbaas_spec):
             changed = True
 
-        if self._add_new_members(endpoints, lbaas_state, lbaas_spec):
+        if (self._has_pods(endpoints) and
+                self._add_new_members(endpoints, lbaas_state, lbaas_spec)):
             changed = True
 
         return changed
@@ -469,6 +474,8 @@ class LoadBalancerHandler(k8s_base.ResourceEventHandler):
         if removed_ids:
             lbaas_state.pools = [p for p in lbaas_state.pools
                                  if p.id not in removed_ids]
+            lbaas_state.members = [m for m in lbaas_state.members
+                                   if m.pool_id not in removed_ids]
         return bool(removed_ids)
 
     def _sync_lbaas_listeners(self, endpoints, lbaas_state, lbaas_spec):
