@@ -40,13 +40,20 @@ class VIFHandler(k8s_base.ResourceEventHandler):
     OBJECT_KIND = constants.K8S_OBJ_POD
 
     def __init__(self):
+        super(VIFHandler, self).__init__()
         self._drv_project = drivers.PodProjectDriver.get_instance()
         self._drv_subnets = drivers.PodSubnetsDriver.get_instance()
         self._drv_sg = drivers.PodSecurityGroupsDriver.get_instance()
         self._drv_vif = drivers.PodVIFDriver.get_instance()
+        # REVISIT(ltomasbo): The VIF Handler should not be aware of the pool
+        # directly. Due to the lack of a mechanism to load and set the
+        # VIFHandler driver, for now it is aware of the pool driver, but this
+        # will be reverted as soon as a mechanism is in place.
+        self._drv_vif_pool = drivers.VIFPoolDriver.get_instance()
+        self._drv_vif_pool.set_vif_driver(self._drv_vif)
 
     def on_present(self, pod):
-        if self._is_host_network(pod) or not self._is_pending(pod):
+        if self._is_host_network(pod) or not self._is_pending_node(pod):
             # REVISIT(ivc): consider an additional configurable check that
             # would allow skipping pods to enable heterogeneous environments
             # where certain pods/namespaces/nodes can be managed by other
@@ -59,17 +66,18 @@ class VIFHandler(k8s_base.ResourceEventHandler):
             project_id = self._drv_project.get_project(pod)
             security_groups = self._drv_sg.get_security_groups(pod, project_id)
             subnets = self._drv_subnets.get_subnets(pod, project_id)
-            vif = self._drv_vif.request_vif(pod, project_id, subnets,
-                                            security_groups)
+            vif = self._drv_vif_pool.request_vif(pod, project_id, subnets,
+                                                 security_groups)
             try:
                 self._set_vif(pod, vif)
             except k_exc.K8sClientException as ex:
                 LOG.debug("Failed to set annotation: %s", ex)
                 # FIXME(ivc): improve granularity of K8sClient exceptions:
                 # only resourceVersion conflict should be ignored
-                self._drv_vif.release_vif(pod, vif)
+                self._drv_vif_pool.release_vif(pod, vif, project_id,
+                                               security_groups)
         elif not vif.active:
-            self._drv_vif.activate_vif(pod, vif)
+            self._drv_vif_pool.activate_vif(pod, vif)
             self._set_vif(pod, vif)
 
     def on_deleted(self, pod):
@@ -79,14 +87,18 @@ class VIFHandler(k8s_base.ResourceEventHandler):
         vif = self._get_vif(pod)
 
         if vif:
-            self._drv_vif.release_vif(pod, vif)
+            project_id = self._drv_project.get_project(pod)
+            security_groups = self._drv_sg.get_security_groups(pod, project_id)
+            self._drv_vif_pool.release_vif(pod, vif, project_id,
+                                           security_groups)
 
     @staticmethod
     def _is_host_network(pod):
         return pod['spec'].get('hostNetwork', False)
 
     @staticmethod
-    def _is_pending(pod):
+    def _is_pending_node(pod):
+        """Checks if Pod is in PENDGING status and has node assigned."""
         try:
             return (pod['spec']['nodeName'] and
                     pod['status']['phase'] == constants.K8S_POD_STATUS_PENDING)
